wagoe.scaffolder.schema

Scaffolder module schemas for module generation inputs and outputs.

Scaffolder module schemas for module generation inputs and outputs.
raw docstring

EntityDefinitionclj

Schema for an entity definition.

Schema for an entity definition.
sourceraw docstring

FieldDefinitionclj

Schema for a field definition in an entity.

Schema for a field definition in an entity.
sourceraw docstring

FieldTypeclj

Supported field types for entity fields.

Supported field types for entity fields.
sourceraw docstring

GeneratedFileclj

Schema for a generated file.

Schema for a generated file.
sourceraw docstring

ModuleGenerationRequestclj

Schema for module generation request.

Schema for module generation request.
sourceraw docstring

ModuleGenerationResultclj

Schema for module generation result.

Schema for module generation result.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries